@@ -2,14 +2,16 @@
 # -*- coding: utf-8 -*-
 
 import json
-import dill as pkl
+import warnings
 from os import path
 import pandas as pd
 from glob import glob
+from termcolor import colored
 from dateutil.parser import parse
-import SplatStats.Battle as bat
-import SplatStats.parsers as par
+import SplatStats.constants as cst
 import SplatStats.auxiliary as aux
+import SplatStats.Battle as bat
+warnings.simplefilter(action='ignore', category=FutureWarning)
 
 class History:
     """
@@ -28,26 +30,31 @@ class History:
         self.outputPath = oPath
         self.inputPath = iPath
         # Get history filepaths -----------------------------------------------
-        hFolders = aux.getHistoryFolders(iPath, expPat='export-*')
+        hFolders = aux.getHistoryFolders(iPath, fldrPat='export-*')
         hFiles = aux.getHistoryFiles(hFolders, pattern='results.json')
         self.historyFiles = hFiles
         # Start the battle files list as empty --------------------------------
-        self.dumpBattlesFromJSONS()
-        self.getBattleFilepaths()
+        # self.dumpBattlesFromJSONS()
+        # self.getBattleFilepaths()
 
     ###########################################################################
     # Dump all battles
     ###########################################################################
     def dumpBattlesFromJSONS(self):
-        for fName in self.historyFiles:
+        fNum = len(self.historyFiles)
+        for (ix, fName) in enumerate(self.historyFiles):
+            # Print progress --------------------------------------------------
+            cpt = colored(f'* Parsing JSONs {ix+1:05d}/{fNum:05d}', 'red')
+            print(cpt, end='\r')
+            # Load JSON -------------------------------------------------------
             with open(fName, 'r') as file:
                 data = json.load(file)
+            # Process battles in file -----------------------------------------
             histSize = len(data)
             for i in range(histSize):
                 bDetail = data[i]['data']['vsHistoryDetail']
                 # Process battle history --------------------------------------
                 battle = bat.Battle(bDetail)
-                battle.alliedTeam
                 # Export battle history ---------------------------------------
                 battle.dumpBattle(self.outputPath)
                 
@@ -59,32 +66,32 @@ class History:
         self.battleFilepaths = battleFilepaths
         
     ###########################################################################
-    # Get player allied history dataframe
+    # Get player history dataframe
     ###########################################################################
     def getPlayerHistory(self, playerName, category='player name'):
+        fNum = len(self.battleFilepaths)
         playerDFs = []
-        for batFile in self.battleFilepaths:
+        for (ix, batFile) in enumerate(self.battleFilepaths):
+            # Print progress --------------------------------------------------
+            cpt = colored(f'* Loading History {ix+1:05d}/{fNum:05d}', 'red')
+            print(cpt, end='\r')
+            # Process battle --------------------------------------------------
             battle = aux.loadBattle(batFile)
             rowA = battle.getAllyByCategory(playerName, category=category)
             rowE = battle.getEnemyByCategory(playerName, category=category)
+            # Append row to list ----------------------------------------------
             if rowA is not None:
                 playerDFs.append(rowA)
             if rowE is not None:
                 playerDFs.append(rowE)
         playerDF = pd.concat(playerDFs, axis=0)
+        playerDF.astype(cst.BATTLE_DTYPES)
+        # Re-arrange dataframe ------------------------------------------------
+        playerDF.sort_values(by='datetime', inplace=True)
         playerDF.reset_index(drop=True, inplace=True)
-        playerDF.drop(['player name', 'player name id'], axis=1, inplace=True)
+        playerDF.drop([
+            'player name', 'player name id', 'self'
+        ], axis=1, inplace=True)
         playerDF.drop_duplicates(inplace=True)
         return  playerDF
-    
-    def getPlayerEnemyHistory(self, playerName, category='player name'):
-        playerDFs = []
-        for batFile in self.battleFilepaths:
-            battle = aux.loadBattle(batFile)
-            row = battle.getEnemyByCategory(playerName, category=category)
-            playerDFs.append(row)
-        playerDF = pd.concat(playerDFs, axis=0)
-        playerDF.reset_index(drop=True, inplace=True)
-        playerDF.drop(['player name', 'player name id'], axis=1, inplace=True)
-        playerDF.drop_duplicates(inplace=True)
-        return  playerDF
\ No newline at end of file
+    
\ No newline at end of file
