@@ -19,13 +19,23 @@ class Player:
     Attributes
     ----------
     name : str
-        Player's in-game name
+        Player's in-game name.
     id : int
-        Player's in-game id
+        Player's in-game id.
+    bPaths : list of paths
+        List of paths for all the battle files to be analyzed.
+    timezone : str
+        Datetime-valid timezone string id for the player's location.
     battlesRecords : list of objects
-        Full list of battle objects
+        Full list of battle objects.
     battlesHistory : dataframe
-        Player's full battle history
+        Full battle history.
+    battlesHistoryByType : set of dataframes
+        Battle history broken up by match types: "Turf War", "Rainmaker", "Splat Zones", "Clam Blitz", "Tower Control"
+    playerStats : set
+        Stats on full battle history.
+    playerStatsByType : set of sets
+        Stats on battle history by match-type
         
     Methods
     -------
@@ -38,11 +48,13 @@ class Player:
         self.id = id
         self.bPaths = bPaths
         self.timezone = timezone
-        # Parse player's battles dataframe ------------------------------------
+        # Parse player's battles dataframes -----------------------------------
         self.battleRecords = self.getBattleRecords()
         self.battlesHistory = self.parsePlayerHistoryFromBattles()
+        self.battlesHistoryByType = self.getPlayerHistoryByTypes()
         # Assign stats --------------------------------------------------------
         self.playerStats = self.calcPlayerStats()
+        self.playerStatsByType = self.calcPlayerStatsByTypes()
 
     ###########################################################################
     # Get battle records
@@ -71,6 +83,13 @@ class Player:
         self.battlesHistory = battlesHistory
         return self.battlesHistory
     
+    def getPlayerHistoryByTypes(self):
+        bTypes = cst.MATCH_TYPES
+        bTypesHist = {
+            bType: self.getBattleRecordsByType(bType) for bType in bTypes
+        }
+        return bTypesHist
+
     ###########################################################################
     # Calculate player stats from history dataframe
     ###########################################################################
@@ -79,3 +98,13 @@ class Player:
         hStats = stt.calcBattleHistoryStats(bHist)
         return hStats
         
+    def calcPlayerStatsByTypes(self):
+        (bTypes, bHists) = (
+            cst.MATCH_TYPES, 
+            self.battlesHistoryByType
+        )
+        hStatsHist = {
+            bType: stt.calcBattleHistoryStats(bHists[bType]) 
+            for bType in bTypes if (bHists[bType].shape[0] > 0)
+        }
+        return hStatsHist
\ No newline at end of file
