@@ -38,8 +38,8 @@ def loadBattle(fPath):
         battle = pkl.load(f)
     return battle
 
-def getHistoryFolders(histPath, expPat='export-*'):
-    histFolders = glob(path.join(histPath, expPat))
+def getHistoryFolders(histPath, fldrPat='export-*'):
+    histFolders = glob(path.join(histPath, fldrPat))
     return histFolders
 
 def getHistoryFiles(histFolders, pattern='results.json'):
@@ -55,3 +55,15 @@ def awardsToStrings(awardsDF, sep='@'):
         awds.append(f"{row['name']}{sep}{row['rank']}{sep}{row['place']}")
     return awds
     
+
+def isNotebook():
+    try:
+        shell = get_ipython().__class__.__name__
+        if shell == 'ZMQInteractiveShell':
+            return True   # Jupyter notebook or qtconsole
+        elif shell == 'TerminalInteractiveShell':
+            return False  # Terminal running IPython
+        else:
+            return False  # Other type (?)
+    except NameError:
+        return False      # Probably standard Python interpreter
